# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.security.authentication.web
import winsdk.windows.security.authentication.web.core
import winsdk.windows.security.credentials
import winsdk.windows.security.cryptography.core
import winsdk.windows.storage.streams
import winsdk.windows.system
import winsdk.windows.web.http

class WebAccountClientViewType(enum.IntEnum):
    ID_ONLY = 0
    ID_AND_PROPERTIES = 1

class WebAccountProviderOperationKind(enum.IntEnum):
    REQUEST_TOKEN = 0
    GET_TOKEN_SILENTLY = 1
    ADD_ACCOUNT = 2
    MANAGE_ACCOUNT = 3
    DELETE_ACCOUNT = 4
    RETRIEVE_COOKIES = 5
    SIGN_OUT_ACCOUNT = 6

class WebAccountScope(enum.IntEnum):
    PER_USER = 0
    PER_APPLICATION = 1

class WebAccountSelectionOptions(enum.IntFlag):
    DEFAULT = 0
    NEW = 0x1

Self = typing.TypeVar('Self')

class WebAccountClientView(winsdk.system.Object):
    account_pairwise_id: str
    application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    type: WebAccountClientViewType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountClientView: ...
    @typing.overload
    def __new__(cls: typing.Type[WebAccountClientView], view_type: WebAccountClientViewType, application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> WebAccountClientView:...
    @typing.overload
    def __new__(cls: typing.Type[WebAccountClientView], view_type: WebAccountClientViewType, application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri], account_pairwise_id: str) -> WebAccountClientView:...

class WebAccountManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountManager: ...
    @typing.overload
    @staticmethod
    def add_web_account_async(web_account_id: str, web_account_user_name: str, props: winsdk.windows.foundation.collections.IMapView[str, str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @typing.overload
    @staticmethod
    def add_web_account_async(web_account_id: str, web_account_user_name: str, props: winsdk.windows.foundation.collections.IMapView[str, str], scope: WebAccountScope) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @typing.overload
    @staticmethod
    def add_web_account_async(web_account_id: str, web_account_user_name: str, props: winsdk.windows.foundation.collections.IMapView[str, str], scope: WebAccountScope, per_user_web_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @typing.overload
    @staticmethod
    def add_web_account_for_user_async(user: typing.Optional[winsdk.windows.system.User], web_account_id: str, web_account_user_name: str, props: winsdk.windows.foundation.collections.IMapView[str, str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @typing.overload
    @staticmethod
    def add_web_account_for_user_async(user: typing.Optional[winsdk.windows.system.User], web_account_id: str, web_account_user_name: str, props: winsdk.windows.foundation.collections.IMapView[str, str], scope: WebAccountScope) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @typing.overload
    @staticmethod
    def add_web_account_for_user_async(user: typing.Optional[winsdk.windows.system.User], web_account_id: str, web_account_user_name: str, props: winsdk.windows.foundation.collections.IMapView[str, str], scope: WebAccountScope, per_user_web_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @staticmethod
    def clear_per_user_from_per_app_account_async(per_app_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def clear_view_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def clear_web_account_picture_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def delete_web_account_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def find_all_provider_web_accounts_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.credentials.WebAccount]]: ...
    @staticmethod
    def find_all_provider_web_accounts_for_user_async(user: typing.Optional[winsdk.windows.system.User]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.credentials.WebAccount]]: ...
    @staticmethod
    def get_per_user_from_per_app_account_async(per_app_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.credentials.WebAccount]: ...
    @staticmethod
    def get_scope(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> WebAccountScope: ...
    @staticmethod
    def get_views_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[WebAccountClientView]]: ...
    @staticmethod
    def invalidate_app_cache_for_account_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def invalidate_app_cache_for_all_accounts_async() -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def pull_cookies_async(uri_string: str, caller_p_f_n: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def push_cookies_async(uri: typing.Optional[winsdk.windows.foundation.Uri], cookies: winsdk.windows.foundation.collections.IVectorView[winsdk.windows.web.http.HttpCookie]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def set_per_app_to_per_user_account_async(per_app_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], per_user_web_account_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def set_scope_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], scope: WebAccountScope) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def set_view_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], view: typing.Optional[WebAccountClientView]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def set_web_account_picture_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], web_account_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def update_web_account_properties_async(web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount], web_account_user_name: str, additional_properties: winsdk.windows.foundation.collections.IMapView[str, str]) -> winsdk.windows.foundation.IAsyncAction: ...

class WebAccountProviderAddAccountOperation(winsdk.system.Object):
    kind: WebAccountProviderOperationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderAddAccountOperation: ...
    def report_completed(self) -> None: ...

class WebAccountProviderDeleteAccountOperation(winsdk.system.Object):
    web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]
    kind: WebAccountProviderOperationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderDeleteAccountOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...

class WebAccountProviderGetTokenSilentOperation(winsdk.system.Object):
    kind: WebAccountProviderOperationKind
    cache_expiration_time: datetime.datetime
    provider_request: typing.Optional[WebProviderTokenRequest]
    provider_responses: typing.Optional[winsdk.windows.foundation.collections.IVector[WebProviderTokenResponse]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderGetTokenSilentOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...
    @typing.overload
    def report_user_interaction_required(self) -> None: ...
    @typing.overload
    def report_user_interaction_required(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...

class WebAccountProviderManageAccountOperation(winsdk.system.Object):
    web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]
    kind: WebAccountProviderOperationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderManageAccountOperation: ...
    def report_completed(self) -> None: ...

class WebAccountProviderRequestTokenOperation(winsdk.system.Object):
    kind: WebAccountProviderOperationKind
    cache_expiration_time: datetime.datetime
    provider_request: typing.Optional[WebProviderTokenRequest]
    provider_responses: typing.Optional[winsdk.windows.foundation.collections.IVector[WebProviderTokenResponse]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderRequestTokenOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...
    def report_user_canceled(self) -> None: ...

class WebAccountProviderRetrieveCookiesOperation(winsdk.system.Object):
    kind: WebAccountProviderOperationKind
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    context: typing.Optional[winsdk.windows.foundation.Uri]
    cookies: typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.web.http.HttpCookie]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderRetrieveCookiesOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...

class WebAccountProviderSignOutAccountOperation(winsdk.system.Object):
    kind: WebAccountProviderOperationKind
    application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    client_id: str
    web_account: typing.Optional[winsdk.windows.security.credentials.WebAccount]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderSignOutAccountOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...

class WebAccountProviderTriggerDetails(winsdk.system.Object):
    operation: typing.Optional[IWebAccountProviderOperation]
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebAccountProviderTriggerDetails: ...

class WebProviderTokenRequest(winsdk.system.Object):
    application_callback_uri: typing.Optional[winsdk.windows.foundation.Uri]
    client_request: typing.Optional[winsdk.windows.security.authentication.web.core.WebTokenRequest]
    web_account_selection_options: WebAccountSelectionOptions
    web_accounts: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.security.credentials.WebAccount]]
    application_package_family_name: str
    application_process_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebProviderTokenRequest: ...
    def check_application_for_capability_async(self, capability_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_application_token_binding_key_async(self, key_type: winsdk.windows.security.authentication.web.TokenBindingKeyType, target: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.security.cryptography.core.CryptographicKey]: ...
    def get_application_token_binding_key_id_async(self, key_type: winsdk.windows.security.authentication.web.TokenBindingKeyType, target: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...

class WebProviderTokenResponse(winsdk.system.Object):
    client_response: typing.Optional[winsdk.windows.security.authentication.web.core.WebTokenResponse]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WebProviderTokenResponse: ...
    def __new__(cls: typing.Type[WebProviderTokenResponse], web_token_response: typing.Optional[winsdk.windows.security.authentication.web.core.WebTokenResponse]) -> WebProviderTokenResponse:...

class IWebAccountProviderBaseReportOperation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderBaseReportOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...

class IWebAccountProviderOperation(winsdk.system.Object):
    kind: WebAccountProviderOperationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderOperation: ...

class IWebAccountProviderSilentReportOperation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderSilentReportOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...
    @typing.overload
    def report_user_interaction_required(self) -> None: ...
    @typing.overload
    def report_user_interaction_required(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...

class IWebAccountProviderTokenObjects(winsdk.system.Object):
    operation: typing.Optional[IWebAccountProviderOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderTokenObjects: ...

class IWebAccountProviderTokenObjects2(winsdk.system.Object):
    user: typing.Optional[winsdk.windows.system.User]
    operation: typing.Optional[IWebAccountProviderOperation]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderTokenObjects2: ...

class IWebAccountProviderTokenOperation(winsdk.system.Object):
    cache_expiration_time: datetime.datetime
    provider_request: typing.Optional[WebProviderTokenRequest]
    provider_responses: typing.Optional[winsdk.windows.foundation.collections.IVector[WebProviderTokenResponse]]
    kind: WebAccountProviderOperationKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderTokenOperation: ...

class IWebAccountProviderUIReportOperation(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IWebAccountProviderUIReportOperation: ...
    def report_completed(self) -> None: ...
    def report_error(self, value: typing.Optional[winsdk.windows.security.authentication.web.core.WebProviderError]) -> None: ...
    def report_user_canceled(self) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.printing
import winsdk.windows.storage.streams

class IppAttributeErrorReason(enum.IntEnum):
    REQUEST_ENTITY_TOO_LARGE = 0
    ATTRIBUTE_NOT_SUPPORTED = 1
    ATTRIBUTE_VALUES_NOT_SUPPORTED = 2
    ATTRIBUTE_NOT_SETTABLE = 3
    CONFLICTING_ATTRIBUTES = 4

class IppAttributeValueKind(enum.IntEnum):
    UNSUPPORTED = 0
    UNKNOWN = 1
    NO_VALUE = 2
    INTEGER = 3
    BOOLEAN = 4
    ENUM = 5
    OCTET_STRING = 6
    DATE_TIME = 7
    RESOLUTION = 8
    RANGE_OF_INTEGER = 9
    COLLECTION = 10
    TEXT_WITH_LANGUAGE = 11
    NAME_WITH_LANGUAGE = 12
    TEXT_WITHOUT_LANGUAGE = 13
    NAME_WITHOUT_LANGUAGE = 14
    KEYWORD = 15
    URI = 16
    URI_SCHEMA = 17
    CHARSET = 18
    NATURAL_LANGUAGE = 19
    MIME_MEDIA_TYPE = 20

class IppResolutionUnit(enum.IntEnum):
    DOTS_PER_INCH = 0
    DOTS_PER_CENTIMETER = 1

class PageConfigurationSource(enum.IntEnum):
    PRINT_JOB_CONFIGURATION = 0
    PDL_CONTENT = 1

Self = typing.TypeVar('Self')

class IppAttributeError(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    reason: IppAttributeErrorReason
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppAttributeError: ...
    def get_unsupported_values(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[IppAttributeValue]]: ...

class IppAttributeValue(winsdk.system.Object):
    kind: IppAttributeValueKind
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppAttributeValue: ...
    @staticmethod
    def create_boolean(value: winsdk.system.Boolean) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_boolean_array(values: typing.Iterable[winsdk.system.Boolean]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_charset(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_charset_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_collection(member_attributes: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, IppAttributeValue]]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_collection_array(member_attributes_array: typing.Iterable[winsdk.windows.foundation.collections.IIterable[winsdk.windows.foundation.collections.IKeyValuePair[str, IppAttributeValue]]]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_date_time(value: datetime.datetime) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_date_time_array(values: typing.Iterable[datetime.datetime]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_enum(value: winsdk.system.Int32) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_enum_array(values: typing.Iterable[winsdk.system.Int32]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_integer(value: winsdk.system.Int32) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_integer_array(values: typing.Iterable[winsdk.system.Int32]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_keyword(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_keyword_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_mime_media(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_mime_media_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_name_with_language(value: typing.Optional[IppTextWithLanguage]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_name_with_language_array(values: typing.Iterable[IppTextWithLanguage]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_name_without_language(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_name_without_language_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_natural_language(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_natural_language_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_no_value() -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_octet_string(value: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_octet_string_array(values: typing.Iterable[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_range_of_integer(value: typing.Optional[IppIntegerRange]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_range_of_integer_array(values: typing.Iterable[IppIntegerRange]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_resolution(value: typing.Optional[IppResolution]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_resolution_array(values: typing.Iterable[IppResolution]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_text_with_language(value: typing.Optional[IppTextWithLanguage]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_text_with_language_array(values: typing.Iterable[IppTextWithLanguage]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_text_without_language(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_text_without_language_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_unknown() -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_unsupported() -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_uri(value: typing.Optional[winsdk.windows.foundation.Uri]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_uri_array(values: typing.Iterable[winsdk.windows.foundation.Uri]) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_uri_schema(value: str) -> typing.Optional[IppAttributeValue]: ...
    @staticmethod
    def create_uri_schema_array(values: typing.Iterable[str]) -> typing.Optional[IppAttributeValue]: ...
    def get_boolean_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Boolean]]: ...
    def get_charset_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...
    def get_collection_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.foundation.collections.IMapView[str, IppAttributeValue]]]: ...
    def get_date_time_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[datetime.datetime]]: ...
    def get_enum_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Int32]]: ...
    def get_integer_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.system.Int32]]: ...
    def get_keyword_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...
    def get_mime_media_type_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...
    def get_name_with_language_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[IppTextWithLanguage]]: ...
    def get_name_without_language_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...
    def get_natural_language_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...
    def get_octet_string_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.storage.streams.IBuffer]]: ...
    def get_range_of_integer_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[IppIntegerRange]]: ...
    def get_resolution_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[IppResolution]]: ...
    def get_text_with_language_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[IppTextWithLanguage]]: ...
    def get_text_without_language_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...
    def get_uri_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[winsdk.windows.foundation.Uri]]: ...
    def get_uri_schema_array(self) -> typing.Optional[winsdk.windows.foundation.collections.IVector[str]]: ...

class IppIntegerRange(winsdk.system.Object):
    end: winsdk.system.Int32
    start: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppIntegerRange: ...
    def __new__(cls: typing.Type[IppIntegerRange], start: winsdk.system.Int32, end: winsdk.system.Int32) -> IppIntegerRange:...

class IppPrintDevice(winsdk.system.Object):
    printer_name: str
    printer_uri: typing.Optional[winsdk.windows.foundation.Uri]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppPrintDevice: ...
    @staticmethod
    def from_id(device_id: str) -> typing.Optional[IppPrintDevice]: ...
    @staticmethod
    def from_printer_name(printer_name: str) -> typing.Optional[IppPrintDevice]: ...
    @staticmethod
    def get_device_selector() -> str: ...
    def get_max_supported_pdf_size(self) -> winsdk.system.UInt64: ...
    def get_max_supported_pdf_version(self) -> str: ...
    def get_pdl_passthrough_provider(self) -> typing.Optional[PdlPassthroughProvider]: ...
    def get_printer_attributes(self, attribute_names: typing.Iterable[str]) -> typing.Optional[winsdk.windows.foundation.collections.IMap[str, IppAttributeValue]]: ...
    def get_printer_attributes_as_buffer(self, attribute_names: typing.Iterable[str]) -> typing.Optional[winsdk.windows.storage.streams.IBuffer]: ...
    @staticmethod
    def is_ipp_printer(printer_name: str) -> winsdk.system.Boolean: ...
    def is_pdl_passthrough_supported(self, pdl_content_type: str) -> winsdk.system.Boolean: ...
    def set_printer_attributes(self, printer_attributes: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, IppAttributeValue]]) -> typing.Optional[IppSetAttributesResult]: ...
    def set_printer_attributes_from_buffer(self, printer_attributes_buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> typing.Optional[IppSetAttributesResult]: ...

class IppResolution(winsdk.system.Object):
    height: winsdk.system.Int32
    unit: IppResolutionUnit
    width: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppResolution: ...
    def __new__(cls: typing.Type[IppResolution], width: winsdk.system.Int32, height: winsdk.system.Int32, unit: IppResolutionUnit) -> IppResolution:...

class IppSetAttributesResult(winsdk.system.Object):
    attribute_errors: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, IppAttributeError]]
    succeeded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppSetAttributesResult: ...

class IppTextWithLanguage(winsdk.system.Object):
    language: str
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IppTextWithLanguage: ...
    def __new__(cls: typing.Type[IppTextWithLanguage], language: str, text: str) -> IppTextWithLanguage:...

class PageConfigurationSettings(winsdk.system.Object):
    size_source: PageConfigurationSource
    orientation_source: PageConfigurationSource
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PageConfigurationSettings: ...
    def __new__(cls: typing.Type[PageConfigurationSettings]) -> PageConfigurationSettings:...

class PdlPassthroughProvider(winsdk.system.Object):
    supported_pdl_content_types: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PdlPassthroughProvider: ...
    def start_print_job_with_print_ticket(self, job_name: str, pdl_content_type: str, print_ticket: typing.Optional[winsdk.windows.storage.streams.IInputStream], page_configuration_settings: typing.Optional[PageConfigurationSettings]) -> typing.Optional[PdlPassthroughTarget]: ...
    def start_print_job_with_task_options(self, job_name: str, pdl_content_type: str, task_options: typing.Optional[winsdk.windows.graphics.printing.PrintTaskOptions], page_configuration_settings: typing.Optional[PageConfigurationSettings]) -> typing.Optional[PdlPassthroughTarget]: ...

class PdlPassthroughTarget(winsdk.system.Object):
    print_job_id: winsdk.system.Int32
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PdlPassthroughTarget: ...
    def close(self) -> None: ...
    def get_output_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...
    def submit(self) -> None: ...

class Print3DDevice(winsdk.system.Object):
    print_schema: typing.Optional[PrintSchema]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Print3DDevice: ...
    @staticmethod
    def from_id_async(device_id: str) -> winsdk.windows.foundation.IAsyncOperation[Print3DDevice]: ...
    @staticmethod
    def get_device_selector() -> str: ...

class PrintSchema(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PrintSchema: ...
    def get_capabilities_async(self, constrain_ticket: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...
    def get_default_print_ticket_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...
    def merge_and_validate_with_default_print_ticket_async(self, delta_ticket: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.geolocation
import winsdk.windows.foundation

class LocationOverrideStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    ALREADY_STARTED = 2
    OTHER = 3

Self = typing.TypeVar('Self')

class GeolocationProvider(winsdk.system.Object):
    is_overridden: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GeolocationProvider: ...
    def __new__(cls: typing.Type[GeolocationProvider]) -> GeolocationProvider:...
    def clear_override_position(self) -> None: ...
    def set_override_position(self, new_position: winsdk.windows.devices.geolocation.BasicGeoposition, position_source: winsdk.windows.devices.geolocation.PositionSource, accuracy_in_meters: winsdk.system.Double) -> LocationOverrideStatus: ...
    def add_is_overridden_changed(self, handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_is_overridden_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.data.text
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams
import winsdk.windows.system
import winsdk.windows.ui
import winsdk.windows.ui.popups
import winsdk.windows.ui.viewmanagement

class ContactAddressKind(enum.IntEnum):
    HOME = 0
    WORK = 1
    OTHER = 2

class ContactAnnotationOperations(enum.IntFlag):
    NONE = 0
    CONTACT_PROFILE = 0x1
    MESSAGE = 0x2
    AUDIO_CALL = 0x4
    VIDEO_CALL = 0x8
    SOCIAL_FEEDS = 0x10
    SHARE = 0x20

class ContactAnnotationStoreAccessType(enum.IntEnum):
    APP_ANNOTATIONS_READ_WRITE = 0
    ALL_ANNOTATIONS_READ_WRITE = 1

class ContactBatchStatus(enum.IntEnum):
    SUCCESS = 0
    SERVER_SEARCH_SYNC_MANAGER_ERROR = 1
    SERVER_SEARCH_UNKNOWN_ERROR = 2

class ContactCardHeaderKind(enum.IntEnum):
    DEFAULT = 0
    BASIC = 1
    ENTERPRISE = 2

class ContactCardTabKind(enum.IntEnum):
    DEFAULT = 0
    EMAIL = 1
    MESSAGING = 2
    PHONE = 3
    VIDEO = 4
    ORGANIZATIONAL_HIERARCHY = 5

class ContactChangeType(enum.IntEnum):
    CREATED = 0
    MODIFIED = 1
    DELETED = 2
    CHANGE_TRACKING_LOST = 3

class ContactDateKind(enum.IntEnum):
    BIRTHDAY = 0
    ANNIVERSARY = 1
    OTHER = 2

class ContactEmailKind(enum.IntEnum):
    PERSONAL = 0
    WORK = 1
    OTHER = 2

class ContactFieldCategory(enum.IntEnum):
    NONE = 0
    HOME = 1
    WORK = 2
    MOBILE = 3
    OTHER = 4

class ContactFieldType(enum.IntEnum):
    EMAIL = 0
    PHONE_NUMBER = 1
    LOCATION = 2
    INSTANT_MESSAGE = 3
    CUSTOM = 4
    CONNECTED_SERVICE_ACCOUNT = 5
    IMPORTANT_DATE = 6
    ADDRESS = 7
    SIGNIFICANT_OTHER = 8
    NOTES = 9
    WEBSITE = 10
    JOB_INFO = 11

class ContactListOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    LIMITED = 1
    FULL = 2
    NONE = 3

class ContactListOtherAppWriteAccess(enum.IntEnum):
    NONE = 0
    SYSTEM_ONLY = 1
    LIMITED = 2

class ContactListSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5
    MANUAL_ACCOUNT_REMOVAL_REQUIRED = 6

class ContactMatchReasonKind(enum.IntEnum):
    NAME = 0
    EMAIL_ADDRESS = 1
    PHONE_NUMBER = 2
    JOB_INFO = 3
    YOMI_NAME = 4
    OTHER = 5

class ContactNameOrder(enum.IntEnum):
    FIRST_NAME_LAST_NAME = 0
    LAST_NAME_FIRST_NAME = 1

class ContactPhoneKind(enum.IntEnum):
    HOME = 0
    MOBILE = 1
    WORK = 2
    OTHER = 3
    PAGER = 4
    BUSINESS_FAX = 5
    HOME_FAX = 6
    COMPANY = 7
    ASSISTANT = 8
    RADIO = 9

class ContactQueryDesiredFields(enum.IntFlag):
    NONE = 0
    PHONE_NUMBER = 0x1
    EMAIL_ADDRESS = 0x2
    POSTAL_ADDRESS = 0x4

class ContactQuerySearchFields(enum.IntFlag):
    NONE = 0
    NAME = 0x1
    EMAIL = 0x2
    PHONE = 0x4
    ALL = 0xffffffff

class ContactQuerySearchScope(enum.IntEnum):
    LOCAL = 0
    SERVER = 1

class ContactRelationship(enum.IntEnum):
    OTHER = 0
    SPOUSE = 1
    PARTNER = 2
    SIBLING = 3
    PARENT = 4
    CHILD = 5

class ContactSelectionMode(enum.IntEnum):
    CONTACTS = 0
    FIELDS = 1

class ContactStoreAccessType(enum.IntEnum):
    APP_CONTACTS_READ_WRITE = 0
    ALL_CONTACTS_READ_ONLY = 1
    ALL_CONTACTS_READ_WRITE = 2

class PinnedContactSurface(enum.IntEnum):
    START_MENU = 0
    TASKBAR = 1

Self = typing.TypeVar('Self')

class AggregateContactManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AggregateContactManager: ...
    def find_raw_contacts_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[Contact]]: ...
    def set_remote_identification_information_async(self, contact_list_id: str, remote_source_id: str, account_id: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_link_contacts_async(self, primary_contact: typing.Optional[Contact], secondary_contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def try_set_preferred_source_for_picture_async(self, aggregate_contact: typing.Optional[Contact], raw_contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def unlink_raw_contact_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncAction: ...

class Contact(winsdk.system.Object):
    thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    name: str
    fields: typing.Optional[winsdk.windows.foundation.collections.IVector[IContactField]]
    id: str
    notes: str
    connected_service_accounts: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactConnectedServiceAccount]]
    emails: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactEmail]]
    addresses: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactAddress]]
    important_dates: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactDate]]
    job_info: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactJobInfo]]
    data_suppliers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    phones: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactPhone]]
    provider_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    significant_others: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactSignificantOther]]
    websites: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactWebsite]]
    source_display_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    text_tone_token: str
    display_name_override: str
    display_picture_user_update_time: datetime.datetime
    nickname: str
    remote_id: str
    ring_tone_token: str
    contact_list_id: str
    large_display_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    small_display_picture: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    sort_name: str
    aggregate_id: str
    full_name: str
    is_aggregate: winsdk.system.Boolean
    is_display_picture_manually_set: winsdk.system.Boolean
    is_me: winsdk.system.Boolean
    yomi_given_name: str
    honorific_name_suffix: str
    yomi_family_name: str
    middle_name: str
    last_name: str
    honorific_name_prefix: str
    first_name: str
    display_name: str
    yomi_display_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Contact: ...
    def __new__(cls: typing.Type[Contact]) -> Contact:...

class ContactAddress(winsdk.system.Object):
    street_address: str
    region: str
    postal_code: str
    locality: str
    kind: ContactAddressKind
    description: str
    country: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactAddress: ...
    def __new__(cls: typing.Type[ContactAddress]) -> ContactAddress:...

class ContactAnnotation(winsdk.system.Object):
    supported_operations: ContactAnnotationOperations
    remote_id: str
    contact_id: str
    annotation_list_id: str
    id: str
    is_disabled: winsdk.system.Boolean
    provider_properties: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    contact_list_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactAnnotation: ...
    def __new__(cls: typing.Type[ContactAnnotation]) -> ContactAnnotation:...

class ContactAnnotationList(winsdk.system.Object):
    id: str
    provider_package_family_name: str
    user_data_account_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactAnnotationList: ...
    def delete_annotation_async(self, annotation: typing.Optional[ContactAnnotation]) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def find_annotations_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactAnnotation]]: ...
    def find_annotations_by_remote_id_async(self, remote_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactAnnotation]]: ...
    def get_annotation_async(self, annotation_id: str) -> winsdk.windows.foundation.IAsyncOperation[ContactAnnotation]: ...
    def try_save_annotation_async(self, annotation: typing.Optional[ContactAnnotation]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class ContactAnnotationStore(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactAnnotationStore: ...
    @typing.overload
    def create_annotation_list_async(self) -> winsdk.windows.foundation.IAsyncOperation[ContactAnnotationList]: ...
    @typing.overload
    def create_annotation_list_async(self, user_data_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[ContactAnnotationList]: ...
    def disable_annotation_async(self, annotation: typing.Optional[ContactAnnotation]) -> winsdk.windows.foundation.IAsyncAction: ...
    def find_annotation_lists_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactAnnotationList]]: ...
    def find_annotations_for_contact_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactAnnotation]]: ...
    def find_annotations_for_contact_list_async(self, contact_list_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactAnnotation]]: ...
    def find_contact_ids_by_email_async(self, email_address: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    def find_contact_ids_by_phone_number_async(self, phone_number: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[str]]: ...
    def get_annotation_list_async(self, annotation_list_id: str) -> winsdk.windows.foundation.IAsyncOperation[ContactAnnotationList]: ...

class ContactBatch(winsdk.system.Object):
    contacts: typing.Optional[winsdk.windows.foundation.collections.IVectorView[Contact]]
    status: ContactBatchStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactBatch: ...

class ContactCardDelayedDataLoader(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactCardDelayedDataLoader: ...
    def close(self) -> None: ...
    def set_data(self, contact: typing.Optional[Contact]) -> None: ...

class ContactCardOptions(winsdk.system.Object):
    initial_tab_kind: ContactCardTabKind
    header_kind: ContactCardHeaderKind
    server_search_contact_list_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactCardOptions: ...
    def __new__(cls: typing.Type[ContactCardOptions]) -> ContactCardOptions:...

class ContactChange(winsdk.system.Object):
    change_type: ContactChangeType
    contact: typing.Optional[Contact]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactChange: ...

class ContactChangeReader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactChangeReader: ...
    def accept_changes(self) -> None: ...
    def accept_changes_through(self, last_change_to_accept: typing.Optional[ContactChange]) -> None: ...
    def read_batch_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactChange]]: ...

class ContactChangeTracker(winsdk.system.Object):
    is_tracking: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactChangeTracker: ...
    def enable(self) -> None: ...
    def get_change_reader(self) -> typing.Optional[ContactChangeReader]: ...
    def reset(self) -> None: ...

class ContactChangedDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactChangedDeferral: ...
    def complete(self) -> None: ...

class ContactChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactChangedEventArgs: ...
    def get_deferral(self) -> typing.Optional[ContactChangedDeferral]: ...

class ContactConnectedServiceAccount(winsdk.system.Object):
    service_name: str
    id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactConnectedServiceAccount: ...
    def __new__(cls: typing.Type[ContactConnectedServiceAccount]) -> ContactConnectedServiceAccount:...

class ContactDate(winsdk.system.Object):
    year: typing.Optional[typing.Optional[winsdk.system.Int32]]
    month: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    kind: ContactDateKind
    description: str
    day: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactDate: ...
    def __new__(cls: typing.Type[ContactDate]) -> ContactDate:...

class ContactEmail(winsdk.system.Object):
    kind: ContactEmailKind
    description: str
    address: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactEmail: ...
    def __new__(cls: typing.Type[ContactEmail]) -> ContactEmail:...

class ContactField(winsdk.system.Object):
    category: ContactFieldCategory
    name: str
    type: ContactFieldType
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactField: ...
    @typing.overload
    def __new__(cls: typing.Type[ContactField], value: str, type: ContactFieldType) -> ContactField:...
    @typing.overload
    def __new__(cls: typing.Type[ContactField], value: str, type: ContactFieldType, category: ContactFieldCategory) -> ContactField:...
    @typing.overload
    def __new__(cls: typing.Type[ContactField], name: str, value: str, type: ContactFieldType, category: ContactFieldCategory) -> ContactField:...

class ContactFieldFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactFieldFactory: ...
    def __new__(cls: typing.Type[ContactFieldFactory]) -> ContactFieldFactory:...
    @typing.overload
    def create_field(self, value: str, type: ContactFieldType) -> typing.Optional[ContactField]: ...
    @typing.overload
    def create_field(self, value: str, type: ContactFieldType, category: ContactFieldCategory) -> typing.Optional[ContactField]: ...
    @typing.overload
    def create_field(self, name: str, value: str, type: ContactFieldType, category: ContactFieldCategory) -> typing.Optional[ContactField]: ...
    @typing.overload
    def create_instant_message(self, user_name: str) -> typing.Optional[ContactInstantMessageField]: ...
    @typing.overload
    def create_instant_message(self, user_name: str, category: ContactFieldCategory) -> typing.Optional[ContactInstantMessageField]: ...
    @typing.overload
    def create_instant_message(self, user_name: str, category: ContactFieldCategory, service: str, display_text: str, verb: typing.Optional[winsdk.windows.foundation.Uri]) -> typing.Optional[ContactInstantMessageField]: ...
    @typing.overload
    def create_location(self, unstructured_address: str) -> typing.Optional[ContactLocationField]: ...
    @typing.overload
    def create_location(self, unstructured_address: str, category: ContactFieldCategory) -> typing.Optional[ContactLocationField]: ...
    @typing.overload
    def create_location(self, unstructured_address: str, category: ContactFieldCategory, street: str, city: str, region: str, country: str, postal_code: str) -> typing.Optional[ContactLocationField]: ...

class ContactGroup(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactGroup: ...

class ContactInformation(winsdk.system.Object):
    custom_fields: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactField]]
    emails: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactField]]
    instant_messages: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactInstantMessageField]]
    locations: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactLocationField]]
    name: str
    phone_numbers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactField]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactInformation: ...
    def get_thumbnail_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...
    def query_custom_fields(self, custom_name: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactField]]: ...

class ContactInstantMessageField(winsdk.system.Object):
    category: ContactFieldCategory
    name: str
    type: ContactFieldType
    value: str
    display_text: str
    launch_uri: typing.Optional[winsdk.windows.foundation.Uri]
    service: str
    user_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactInstantMessageField: ...
    @typing.overload
    def __new__(cls: typing.Type[ContactInstantMessageField], user_name: str) -> ContactInstantMessageField:...
    @typing.overload
    def __new__(cls: typing.Type[ContactInstantMessageField], user_name: str, category: ContactFieldCategory) -> ContactInstantMessageField:...
    @typing.overload
    def __new__(cls: typing.Type[ContactInstantMessageField], user_name: str, category: ContactFieldCategory, service: str, display_text: str, verb: typing.Optional[winsdk.windows.foundation.Uri]) -> ContactInstantMessageField:...

class ContactJobInfo(winsdk.system.Object):
    title: str
    office: str
    manager: str
    description: str
    department: str
    company_yomi_name: str
    company_name: str
    company_address: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactJobInfo: ...
    def __new__(cls: typing.Type[ContactJobInfo]) -> ContactJobInfo:...

class ContactLaunchActionVerbs(winsdk.system.Object):
    call: typing.ClassVar[str]
    map: typing.ClassVar[str]
    message: typing.ClassVar[str]
    post: typing.ClassVar[str]
    video_call: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactLaunchActionVerbs: ...

class ContactList(winsdk.system.Object):
    supports_server_search: winsdk.system.Boolean
    is_hidden: winsdk.system.Boolean
    other_app_write_access: ContactListOtherAppWriteAccess
    display_name: str
    other_app_read_access: ContactListOtherAppReadAccess
    change_tracker: typing.Optional[ContactChangeTracker]
    source_display_name: str
    id: str
    sync_manager: typing.Optional[ContactListSyncManager]
    user_data_account_id: str
    sync_constraints: typing.Optional[ContactListSyncConstraints]
    limited_write_operations: typing.Optional[ContactListLimitedWriteOperations]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactList: ...
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def delete_contact_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_change_tracker(self, identity: str) -> typing.Optional[ContactChangeTracker]: ...
    def get_contact_async(self, contact_id: str) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def get_contact_from_remote_id_async(self, remote_id: str) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    @typing.overload
    def get_contact_reader(self) -> typing.Optional[ContactReader]: ...
    @typing.overload
    def get_contact_reader(self, options: typing.Optional[ContactQueryOptions]) -> typing.Optional[ContactReader]: ...
    def get_me_contact_async(self) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def register_sync_manager_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def save_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def save_contact_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncAction: ...
    def add_contact_changed(self, value: winsdk.windows.foundation.TypedEventHandler[ContactList, ContactChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_contact_changed(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ContactListLimitedWriteOperations(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListLimitedWriteOperations: ...
    def try_create_or_update_contact_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_delete_contact_async(self, contact_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class ContactListSyncConstraints(winsdk.system.Object):
    can_sync_descriptions: winsdk.system.Boolean
    max_company_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_child_relationships: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_business_fax_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_birthday_dates: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_assistant_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_other_addresses: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_anniversary_dates: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_home_addresses: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_other_dates: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_mobile_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_job_info: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_home_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_home_fax_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_other_email_addresses: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_personal_email_addresses: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_partner_relationships: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_parent_relationships: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_pager_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_other_relationships: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_other_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_radio_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_work_phone_numbers: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_work_email_addresses: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_work_addresses: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_websites: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_spouse_relationships: typing.Optional[typing.Optional[winsdk.system.Int32]]
    max_sibling_relationships: typing.Optional[typing.Optional[winsdk.system.Int32]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListSyncConstraints: ...

class ContactListSyncManager(winsdk.system.Object):
    status: ContactListSyncStatus
    last_successful_sync_time: datetime.datetime
    last_attempted_sync_time: datetime.datetime
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactListSyncManager: ...
    def sync_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_sync_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactListSyncManager, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sync_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ContactLocationField(winsdk.system.Object):
    category: ContactFieldCategory
    name: str
    type: ContactFieldType
    value: str
    city: str
    country: str
    postal_code: str
    region: str
    street: str
    unstructured_address: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactLocationField: ...
    @typing.overload
    def __new__(cls: typing.Type[ContactLocationField], unstructured_address: str) -> ContactLocationField:...
    @typing.overload
    def __new__(cls: typing.Type[ContactLocationField], unstructured_address: str, category: ContactFieldCategory) -> ContactLocationField:...
    @typing.overload
    def __new__(cls: typing.Type[ContactLocationField], unstructured_address: str, category: ContactFieldCategory, street: str, city: str, region: str, country: str, postal_code: str) -> ContactLocationField:...

class ContactManager(winsdk.system.Object):
    system_sort_order: typing.ClassVar[ContactNameOrder]
    system_display_name_order: typing.ClassVar[ContactNameOrder]
    include_middle_name_in_system_display_and_sort: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactManager: ...
    @typing.overload
    @staticmethod
    def convert_contact_to_v_card_async(contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...
    @typing.overload
    @staticmethod
    def convert_contact_to_v_card_async(contact: typing.Optional[Contact], max_bytes: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...
    @staticmethod
    def convert_v_card_to_contact_async(v_card: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[ContactManagerForUser]: ...
    @staticmethod
    def is_show_contact_card_supported() -> winsdk.system.Boolean: ...
    @staticmethod
    def is_show_delay_loaded_contact_card_supported() -> winsdk.system.Boolean: ...
    @staticmethod
    def is_show_full_contact_card_supported_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def request_annotation_store_async(access_type: ContactAnnotationStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[ContactAnnotationStore]: ...
    @typing.overload
    @staticmethod
    def request_store_async() -> winsdk.windows.foundation.IAsyncOperation[ContactStore]: ...
    @typing.overload
    @staticmethod
    def request_store_async(access_type: ContactStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[ContactStore]: ...
    @typing.overload
    @staticmethod
    def show_contact_card(contact: typing.Optional[Contact], selection: winsdk.windows.foundation.Rect) -> None: ...
    @typing.overload
    @staticmethod
    def show_contact_card(contact: typing.Optional[Contact], selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement) -> None: ...
    @typing.overload
    @staticmethod
    def show_contact_card(contact: typing.Optional[Contact], selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement, contact_card_options: typing.Optional[ContactCardOptions]) -> None: ...
    @typing.overload
    @staticmethod
    def show_delay_loaded_contact_card(contact: typing.Optional[Contact], selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement) -> typing.Optional[ContactCardDelayedDataLoader]: ...
    @typing.overload
    @staticmethod
    def show_delay_loaded_contact_card(contact: typing.Optional[Contact], selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement, contact_card_options: typing.Optional[ContactCardOptions]) -> typing.Optional[ContactCardDelayedDataLoader]: ...
    @staticmethod
    def show_full_contact_card(contact: typing.Optional[Contact], full_contact_card_options: typing.Optional[FullContactCardOptions]) -> None: ...

class ContactManagerForUser(winsdk.system.Object):
    system_sort_order: ContactNameOrder
    system_display_name_order: ContactNameOrder
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactManagerForUser: ...
    @typing.overload
    def convert_contact_to_v_card_async(self, contact: typing.Optional[Contact]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...
    @typing.overload
    def convert_contact_to_v_card_async(self, contact: typing.Optional[Contact], max_bytes: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.RandomAccessStreamReference]: ...
    def convert_v_card_to_contact_async(self, v_card: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def request_annotation_store_async(self, access_type: ContactAnnotationStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[ContactAnnotationStore]: ...
    def request_store_async(self, access_type: ContactStoreAccessType) -> winsdk.windows.foundation.IAsyncOperation[ContactStore]: ...
    def show_full_contact_card(self, contact: typing.Optional[Contact], full_contact_card_options: typing.Optional[FullContactCardOptions]) -> None: ...

class ContactMatchReason(winsdk.system.Object):
    field: ContactMatchReasonKind
    segments: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.data.text.TextSegment]]
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactMatchReason: ...

class ContactPanel(winsdk.system.Object):
    header_color: typing.Optional[typing.Optional[winsdk.windows.ui.Color]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactPanel: ...
    def close_panel(self) -> None: ...
    def add_closing(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactPanel, ContactPanelClosingEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_closing(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_launch_full_app_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[ContactPanel, ContactPanelLaunchFullAppRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_launch_full_app_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ContactPanelClosingEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactPanelClosingEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class ContactPanelLaunchFullAppRequestedEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactPanelLaunchFullAppRequestedEventArgs: ...

class ContactPhone(winsdk.system.Object):
    number: str
    kind: ContactPhoneKind
    description: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactPhone: ...
    def __new__(cls: typing.Type[ContactPhone]) -> ContactPhone:...

class ContactPicker(winsdk.system.Object):
    selection_mode: ContactSelectionMode
    commit_button_text: str
    desired_fields: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    desired_fields_with_contact_field_type: typing.Optional[winsdk.windows.foundation.collections.IVector[ContactFieldType]]
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactPicker: ...
    def __new__(cls: typing.Type[ContactPicker]) -> ContactPicker:...
    @staticmethod
    def create_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[ContactPicker]: ...
    @staticmethod
    def is_supported_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def pick_contact_async(self) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def pick_contacts_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[Contact]]: ...
    def pick_multiple_contacts_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactInformation]]: ...
    def pick_single_contact_async(self) -> winsdk.windows.foundation.IAsyncOperation[ContactInformation]: ...

class ContactQueryOptions(winsdk.system.Object):
    include_contacts_from_hidden_lists: winsdk.system.Boolean
    desired_operations: ContactAnnotationOperations
    desired_fields: ContactQueryDesiredFields
    annotation_list_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    contact_list_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    text_search: typing.Optional[ContactQueryTextSearch]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactQueryOptions: ...
    @typing.overload
    def __new__(cls: typing.Type[ContactQueryOptions], text: str) -> ContactQueryOptions:...
    @typing.overload
    def __new__(cls: typing.Type[ContactQueryOptions], text: str, fields: ContactQuerySearchFields) -> ContactQueryOptions:...
    @typing.overload
    def __new__(cls: typing.Type[ContactQueryOptions]) -> ContactQueryOptions:...

class ContactQueryTextSearch(winsdk.system.Object):
    text: str
    search_scope: ContactQuerySearchScope
    fields: ContactQuerySearchFields
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactQueryTextSearch: ...

class ContactReader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactReader: ...
    def get_matching_properties_with_match_reason(self, contact: typing.Optional[Contact]) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[ContactMatchReason]]: ...
    def read_batch_async(self) -> winsdk.windows.foundation.IAsyncOperation[ContactBatch]: ...

class ContactSignificantOther(winsdk.system.Object):
    name: str
    description: str
    relationship: ContactRelationship
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactSignificantOther: ...
    def __new__(cls: typing.Type[ContactSignificantOther]) -> ContactSignificantOther:...

class ContactStore(winsdk.system.Object):
    aggregate_contact_manager: typing.Optional[AggregateContactManager]
    change_tracker: typing.Optional[ContactChangeTracker]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactStore: ...
    @typing.overload
    def create_contact_list_async(self, display_name: str) -> winsdk.windows.foundation.IAsyncOperation[ContactList]: ...
    @typing.overload
    def create_contact_list_async(self, display_name: str, user_data_account_id: str) -> winsdk.windows.foundation.IAsyncOperation[ContactList]: ...
    def find_contact_lists_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[ContactList]]: ...
    @typing.overload
    def find_contacts_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[Contact]]: ...
    @typing.overload
    def find_contacts_async(self, search_text: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[Contact]]: ...
    def get_change_tracker(self, identity: str) -> typing.Optional[ContactChangeTracker]: ...
    def get_contact_async(self, contact_id: str) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def get_contact_list_async(self, contact_list_id: str) -> winsdk.windows.foundation.IAsyncOperation[ContactList]: ...
    @typing.overload
    def get_contact_reader(self) -> typing.Optional[ContactReader]: ...
    @typing.overload
    def get_contact_reader(self, options: typing.Optional[ContactQueryOptions]) -> typing.Optional[ContactReader]: ...
    def get_me_contact_async(self) -> winsdk.windows.foundation.IAsyncOperation[Contact]: ...
    def add_contact_changed(self, value: winsdk.windows.foundation.TypedEventHandler[ContactStore, ContactChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_contact_changed(self, value: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ContactStoreNotificationTriggerDetails(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactStoreNotificationTriggerDetails: ...

class ContactWebsite(winsdk.system.Object):
    uri: typing.Optional[winsdk.windows.foundation.Uri]
    description: str
    raw_value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ContactWebsite: ...
    def __new__(cls: typing.Type[ContactWebsite]) -> ContactWebsite:...

class FullContactCardOptions(winsdk.system.Object):
    desired_remaining_view: winsdk.windows.ui.viewmanagement.ViewSizePreference
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FullContactCardOptions: ...
    def __new__(cls: typing.Type[FullContactCardOptions]) -> FullContactCardOptions:...

class KnownContactField(winsdk.system.Object):
    email: typing.ClassVar[str]
    instant_message: typing.ClassVar[str]
    location: typing.ClassVar[str]
    phone_number: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownContactField: ...
    @staticmethod
    def convert_name_to_type(name: str) -> ContactFieldType: ...
    @staticmethod
    def convert_type_to_name(type: ContactFieldType) -> str: ...

class PinnedContactIdsQueryResult(winsdk.system.Object):
    contact_ids: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PinnedContactIdsQueryResult: ...

class PinnedContactManager(winsdk.system.Object):
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PinnedContactManager: ...
    @staticmethod
    def get_default() -> typing.Optional[PinnedContactManager]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[PinnedContactManager]: ...
    def get_pinned_contact_ids_async(self) -> winsdk.windows.foundation.IAsyncOperation[PinnedContactIdsQueryResult]: ...
    def is_contact_pinned(self, contact: typing.Optional[Contact], surface: PinnedContactSurface) -> winsdk.system.Boolean: ...
    def is_pin_surface_supported(self, surface: PinnedContactSurface) -> winsdk.system.Boolean: ...
    @staticmethod
    def is_supported() -> winsdk.system.Boolean: ...
    def request_pin_contact_async(self, contact: typing.Optional[Contact], surface: PinnedContactSurface) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def request_pin_contacts_async(self, contacts: typing.Iterable[Contact], surface: PinnedContactSurface) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def request_unpin_contact_async(self, contact: typing.Optional[Contact], surface: PinnedContactSurface) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def signal_contact_activity(self, contact: typing.Optional[Contact]) -> None: ...

class IContactField(winsdk.system.Object):
    category: ContactFieldCategory
    name: str
    type: ContactFieldType
    value: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContactField: ...

class IContactFieldFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContactFieldFactory: ...
    @typing.overload
    def create_field(self, value: str, type: ContactFieldType) -> typing.Optional[ContactField]: ...
    @typing.overload
    def create_field(self, value: str, type: ContactFieldType, category: ContactFieldCategory) -> typing.Optional[ContactField]: ...
    @typing.overload
    def create_field(self, name: str, value: str, type: ContactFieldType, category: ContactFieldCategory) -> typing.Optional[ContactField]: ...

class IContactInstantMessageFieldFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContactInstantMessageFieldFactory: ...
    @typing.overload
    def create_instant_message(self, user_name: str) -> typing.Optional[ContactInstantMessageField]: ...
    @typing.overload
    def create_instant_message(self, user_name: str, category: ContactFieldCategory) -> typing.Optional[ContactInstantMessageField]: ...
    @typing.overload
    def create_instant_message(self, user_name: str, category: ContactFieldCategory, service: str, display_text: str, verb: typing.Optional[winsdk.windows.foundation.Uri]) -> typing.Optional[ContactInstantMessageField]: ...

class IContactLocationFieldFactory(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IContactLocationFieldFactory: ...
    @typing.overload
    def create_location(self, unstructured_address: str) -> typing.Optional[ContactLocationField]: ...
    @typing.overload
    def create_location(self, unstructured_address: str, category: ContactFieldCategory) -> typing.Optional[ContactLocationField]: ...
    @typing.overload
    def create_location(self, unstructured_address: str, category: ContactFieldCategory, street: str, city: str, region: str, country: str, postal_code: str) -> typing.Optional[ContactLocationField]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.AppService")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.system.remotesystems
except ImportError:
    pass

class AppServiceClosedStatus(enum.IntEnum):
    COMPLETED = 0
    CANCELED = 1
    RESOURCE_LIMITS_EXCEEDED = 2
    UNKNOWN = 3

class AppServiceConnectionStatus(enum.IntEnum):
    SUCCESS = 0
    APP_NOT_INSTALLED = 1
    APP_UNAVAILABLE = 2
    APP_SERVICE_UNAVAILABLE = 3
    UNKNOWN = 4
    REMOTE_SYSTEM_UNAVAILABLE = 5
    REMOTE_SYSTEM_NOT_SUPPORTED_BY_APP = 6
    NOT_AUTHORIZED = 7
    AUTHENTICATION_ERROR = 8
    NETWORK_NOT_AVAILABLE = 9
    DISABLED_BY_POLICY = 10
    WEB_SERVICE_UNAVAILABLE = 11

class AppServiceResponseStatus(enum.IntEnum):
    SUCCESS = 0
    FAILURE = 1
    RESOURCE_LIMITS_EXCEEDED = 2
    UNKNOWN = 3
    REMOTE_SYSTEM_UNAVAILABLE = 4
    MESSAGE_SIZE_TOO_LARGE = 5
    APP_UNAVAILABLE = 6
    AUTHENTICATION_ERROR = 7
    NETWORK_NOT_AVAILABLE = 8
    DISABLED_BY_POLICY = 9
    WEB_SERVICE_UNAVAILABLE = 10

class StatelessAppServiceResponseStatus(enum.IntEnum):
    SUCCESS = 0
    APP_NOT_INSTALLED = 1
    APP_UNAVAILABLE = 2
    APP_SERVICE_UNAVAILABLE = 3
    REMOTE_SYSTEM_UNAVAILABLE = 4
    REMOTE_SYSTEM_NOT_SUPPORTED_BY_APP = 5
    NOT_AUTHORIZED = 6
    RESOURCE_LIMITS_EXCEEDED = 7
    MESSAGE_SIZE_TOO_LARGE = 8
    FAILURE = 9
    UNKNOWN = 10
    AUTHENTICATION_ERROR = 11
    NETWORK_NOT_AVAILABLE = 12
    DISABLED_BY_POLICY = 13
    WEB_SERVICE_UNAVAILABLE = 14

_ns_module._register_AppServiceClosedStatus(AppServiceClosedStatus)
_ns_module._register_AppServiceConnectionStatus(AppServiceConnectionStatus)
_ns_module._register_AppServiceResponseStatus(AppServiceResponseStatus)
_ns_module._register_StatelessAppServiceResponseStatus(StatelessAppServiceResponseStatus)

AppServiceCatalog = _ns_module.AppServiceCatalog
AppServiceClosedEventArgs = _ns_module.AppServiceClosedEventArgs
AppServiceConnection = _ns_module.AppServiceConnection
AppServiceDeferral = _ns_module.AppServiceDeferral
AppServiceRequest = _ns_module.AppServiceRequest
AppServiceRequestReceivedEventArgs = _ns_module.AppServiceRequestReceivedEventArgs
AppServiceResponse = _ns_module.AppServiceResponse
AppServiceTriggerDetails = _ns_module.AppServiceTriggerDetails
StatelessAppServiceResponse = _ns_module.StatelessAppServiceResponse



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Management.Policies")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class NamedPolicyKind(enum.IntEnum):
    INVALID = 0
    BINARY = 1
    BOOLEAN = 2
    INT32 = 3
    INT64 = 4
    STRING = 5

_ns_module._register_NamedPolicyKind(NamedPolicyKind)

NamedPolicy = _ns_module.NamedPolicy
NamedPolicyData = _ns_module.NamedPolicyData



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.enumeration
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media.capture
import winsdk.windows.media.devices.core
import winsdk.windows.media.mediaproperties
import winsdk.windows.storage.streams

class AdvancedPhotoMode(enum.IntEnum):
    AUTO = 0
    STANDARD = 1
    HDR = 2
    LOW_LIGHT = 3

class AudioDeviceRole(enum.IntEnum):
    DEFAULT = 0
    COMMUNICATIONS = 1

class AutoFocusRange(enum.IntEnum):
    FULL_RANGE = 0
    MACRO = 1
    NORMAL = 2

class CameraOcclusionKind(enum.IntEnum):
    LID = 0
    CAMERA_HARDWARE = 1

class CameraStreamState(enum.IntEnum):
    NOT_STREAMING = 0
    STREAMING = 1
    BLOCKED_FOR_PRIVACY = 2
    SHUTDOWN = 3

class CaptureSceneMode(enum.IntEnum):
    AUTO = 0
    MANUAL = 1
    MACRO = 2
    PORTRAIT = 3
    SPORT = 4
    SNOW = 5
    NIGHT = 6
    BEACH = 7
    SUNSET = 8
    CANDLELIGHT = 9
    LANDSCAPE = 10
    NIGHT_PORTRAIT = 11
    BACKLIT = 12

class CaptureUse(enum.IntEnum):
    NONE = 0
    PHOTO = 1
    VIDEO = 2

class ColorTemperaturePreset(enum.IntEnum):
    AUTO = 0
    MANUAL = 1
    CLOUDY = 2
    DAYLIGHT = 3
    FLASH = 4
    FLUORESCENT = 5
    TUNGSTEN = 6
    CANDLELIGHT = 7

class DigitalWindowMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class FocusMode(enum.IntEnum):
    AUTO = 0
    SINGLE = 1
    CONTINUOUS = 2
    MANUAL = 3

class FocusPreset(enum.IntEnum):
    AUTO = 0
    MANUAL = 1
    AUTO_MACRO = 2
    AUTO_NORMAL = 3
    AUTO_INFINITY = 4
    AUTO_HYPERFOCAL = 5

class HdrVideoMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class InfraredTorchMode(enum.IntEnum):
    OFF = 0
    ON = 1
    ALTERNATING_FRAME_ILLUMINATION = 2

class IsoSpeedPreset(enum.IntEnum):
    AUTO = 0
    ISO50 = 1
    ISO80 = 2
    ISO100 = 3
    ISO200 = 4
    ISO400 = 5
    ISO800 = 6
    ISO1600 = 7
    ISO3200 = 8
    ISO6400 = 9
    ISO12800 = 10
    ISO25600 = 11

class ManualFocusDistance(enum.IntEnum):
    INFINITY = 0
    HYPERFOCAL = 1
    NEAREST = 2

class MediaCaptureFocusState(enum.IntEnum):
    UNINITIALIZED = 0
    LOST = 1
    SEARCHING = 2
    FOCUSED = 3
    FAILED = 4

class MediaCaptureOptimization(enum.IntEnum):
    DEFAULT = 0
    QUALITY = 1
    LATENCY = 2
    POWER = 3
    LATENCY_THEN_QUALITY = 4
    LATENCY_THEN_POWER = 5
    POWER_AND_QUALITY = 6

class MediaCapturePauseBehavior(enum.IntEnum):
    RETAIN_HARDWARE_RESOURCES = 0
    RELEASE_HARDWARE_RESOURCES = 1

class OpticalImageStabilizationMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class RegionOfInterestType(enum.IntEnum):
    UNKNOWN = 0
    FACE = 1

class SendCommandStatus(enum.IntEnum):
    SUCCESS = 0
    DEVICE_NOT_AVAILABLE = 1

class TelephonyKey(enum.IntEnum):
    D0 = 0
    D1 = 1
    D2 = 2
    D3 = 3
    D4 = 4
    D5 = 5
    D6 = 6
    D7 = 7
    D8 = 8
    D9 = 9
    STAR = 10
    POUND = 11
    A = 12
    B = 13
    C = 14
    D = 15

class VideoDeviceControllerGetDevicePropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    BUFFER_TOO_SMALL = 2
    NOT_SUPPORTED = 3
    DEVICE_NOT_AVAILABLE = 4
    MAX_PROPERTY_VALUE_SIZE_TOO_SMALL = 5
    MAX_PROPERTY_VALUE_SIZE_REQUIRED = 6

class VideoDeviceControllerSetDevicePropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    NOT_SUPPORTED = 2
    INVALID_VALUE = 3
    DEVICE_NOT_AVAILABLE = 4
    NOT_IN_CONTROL = 5

class VideoTemporalDenoisingMode(enum.IntEnum):
    OFF = 0
    ON = 1
    AUTO = 2

class ZoomTransitionMode(enum.IntEnum):
    AUTO = 0
    DIRECT = 1
    SMOOTH = 2

Self = typing.TypeVar('Self')

class AdvancedPhotoCaptureSettings(winsdk.system.Object):
    mode: AdvancedPhotoMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AdvancedPhotoCaptureSettings: ...
    def __new__(cls: typing.Type[AdvancedPhotoCaptureSettings]) -> AdvancedPhotoCaptureSettings:...

class AdvancedPhotoControl(winsdk.system.Object):
    mode: AdvancedPhotoMode
    supported: winsdk.system.Boolean
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AdvancedPhotoMode]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AdvancedPhotoControl: ...
    def configure(self, settings: typing.Optional[AdvancedPhotoCaptureSettings]) -> None: ...

class AudioDeviceController(winsdk.system.Object):
    volume_percent: winsdk.system.Single
    muted: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioDeviceController: ...
    def get_available_media_stream_properties(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]]: ...
    def get_media_stream_properties(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType) -> typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]: ...
    def set_media_stream_properties_async(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType, media_encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]) -> winsdk.windows.foundation.IAsyncAction: ...

class AudioDeviceModule(winsdk.system.Object):
    class_id: str
    display_name: str
    instance_id: winsdk.system.UInt32
    major_version: winsdk.system.UInt32
    minor_version: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioDeviceModule: ...
    def send_command_async(self, command: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperation[ModuleCommandResult]: ...

class AudioDeviceModuleNotificationEventArgs(winsdk.system.Object):
    module: typing.Optional[AudioDeviceModule]
    notification_data: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioDeviceModuleNotificationEventArgs: ...

class AudioDeviceModulesManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioDeviceModulesManager: ...
    def __new__(cls: typing.Type[AudioDeviceModulesManager], device_id: str) -> AudioDeviceModulesManager:...
    def find_all(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[AudioDeviceModule]]: ...
    def find_all_by_id(self, module_id: str) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[AudioDeviceModule]]: ...
    def add_module_notification_received(self, handler: winsdk.windows.foundation.TypedEventHandler[AudioDeviceModulesManager, AudioDeviceModuleNotificationEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_module_notification_received(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CallControl(winsdk.system.Object):
    has_ringer: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CallControl: ...
    def end_call(self, call_token: winsdk.system.UInt64) -> None: ...
    @staticmethod
    def from_id(device_id: str) -> typing.Optional[CallControl]: ...
    @staticmethod
    def get_default() -> typing.Optional[CallControl]: ...
    def indicate_active_call(self, call_token: winsdk.system.UInt64) -> None: ...
    def indicate_new_incoming_call(self, enable_ringer: winsdk.system.Boolean, caller_id: str) -> winsdk.system.UInt64: ...
    def indicate_new_outgoing_call(self) -> winsdk.system.UInt64: ...
    def add_answer_requested(self, handler: typing.Optional[CallControlEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_answer_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_audio_transfer_requested(self, handler: typing.Optional[CallControlEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_audio_transfer_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_dial_requested(self, handler: typing.Optional[DialRequestedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_dial_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_hang_up_requested(self, handler: typing.Optional[CallControlEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_hang_up_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_keypad_pressed(self, handler: typing.Optional[KeypadPressedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_keypad_pressed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_redial_requested(self, handler: typing.Optional[RedialRequestedEventHandler]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_redial_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CameraOcclusionInfo(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraOcclusionInfo: ...
    def get_state(self) -> typing.Optional[CameraOcclusionState]: ...
    def is_occlusion_kind_supported(self, occlusion_kind: CameraOcclusionKind) -> winsdk.system.Boolean: ...
    def add_state_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[CameraOcclusionInfo, CameraOcclusionStateChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_state_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CameraOcclusionState(winsdk.system.Object):
    is_occluded: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraOcclusionState: ...
    def is_occlusion_kind(self, occlusion_kind: CameraOcclusionKind) -> winsdk.system.Boolean: ...

class CameraOcclusionStateChangedEventArgs(winsdk.system.Object):
    state: typing.Optional[CameraOcclusionState]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CameraOcclusionStateChangedEventArgs: ...

class DefaultAudioCaptureDeviceChangedEventArgs(winsdk.system.Object):
    id: str
    role: AudioDeviceRole
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DefaultAudioCaptureDeviceChangedEventArgs: ...

class DefaultAudioRenderDeviceChangedEventArgs(winsdk.system.Object):
    id: str
    role: AudioDeviceRole
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DefaultAudioRenderDeviceChangedEventArgs: ...

class DialRequestedEventArgs(winsdk.system.Object):
    contact: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialRequestedEventArgs: ...
    def handled(self) -> None: ...

class DigitalWindowBounds(winsdk.system.Object):
    scale: winsdk.system.Double
    normalized_origin_top: winsdk.system.Double
    normalized_origin_left: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DigitalWindowBounds: ...
    def __new__(cls: typing.Type[DigitalWindowBounds]) -> DigitalWindowBounds:...

class DigitalWindowCapability(winsdk.system.Object):
    height: winsdk.system.Int32
    max_scale_value: winsdk.system.Double
    min_scale_value: winsdk.system.Double
    min_scale_value_without_upsampling: winsdk.system.Double
    normalized_field_of_view_limit: winsdk.windows.foundation.Rect
    width: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DigitalWindowCapability: ...

class DigitalWindowControl(winsdk.system.Object):
    current_mode: DigitalWindowMode
    is_supported: winsdk.system.Boolean
    supported_capabilities: typing.Optional[winsdk.windows.foundation.collections.IVectorView[DigitalWindowCapability]]
    supported_modes: DigitalWindowMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DigitalWindowControl: ...
    @typing.overload
    def configure(self, digital_window_mode: DigitalWindowMode) -> None: ...
    @typing.overload
    def configure(self, digital_window_mode: DigitalWindowMode, digital_window_bounds: typing.Optional[DigitalWindowBounds]) -> None: ...
    def get_bounds(self) -> typing.Optional[DigitalWindowBounds]: ...
    def get_capability_for_size(self, width: winsdk.system.Int32, height: winsdk.system.Int32) -> typing.Optional[DigitalWindowCapability]: ...

class ExposureCompensationControl(winsdk.system.Object):
    max: winsdk.system.Single
    min: winsdk.system.Single
    step: winsdk.system.Single
    supported: winsdk.system.Boolean
    value: winsdk.system.Single
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExposureCompensationControl: ...
    def set_value_async(self, value: winsdk.system.Single) -> winsdk.windows.foundation.IAsyncAction: ...

class ExposureControl(winsdk.system.Object):
    auto: winsdk.system.Boolean
    max: datetime.timedelta
    min: datetime.timedelta
    step: datetime.timedelta
    supported: winsdk.system.Boolean
    value: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExposureControl: ...
    def set_auto_async(self, value: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_value_async(self, shutter_duration: datetime.timedelta) -> winsdk.windows.foundation.IAsyncAction: ...

class ExposurePriorityVideoControl(winsdk.system.Object):
    enabled: winsdk.system.Boolean
    supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ExposurePriorityVideoControl: ...

class FlashControl(winsdk.system.Object):
    red_eye_reduction: winsdk.system.Boolean
    power_percent: winsdk.system.Single
    enabled: winsdk.system.Boolean
    auto: winsdk.system.Boolean
    power_supported: winsdk.system.Boolean
    red_eye_reduction_supported: winsdk.system.Boolean
    supported: winsdk.system.Boolean
    assistant_light_enabled: winsdk.system.Boolean
    assistant_light_supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FlashControl: ...

class FocusControl(winsdk.system.Object):
    max: winsdk.system.UInt32
    min: winsdk.system.UInt32
    preset: FocusPreset
    step: winsdk.system.UInt32
    supported: winsdk.system.Boolean
    supported_presets: typing.Optional[winsdk.windows.foundation.collections.IVectorView[FocusPreset]]
    value: winsdk.system.UInt32
    focus_changed_supported: winsdk.system.Boolean
    focus_state: MediaCaptureFocusState
    mode: FocusMode
    supported_focus_distances: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ManualFocusDistance]]
    supported_focus_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[FocusMode]]
    supported_focus_ranges: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AutoFocusRange]]
    wait_for_focus_supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FocusControl: ...
    def configure(self, settings: typing.Optional[FocusSettings]) -> None: ...
    def focus_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def lock_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def set_preset_async(self, preset: FocusPreset) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def set_preset_async(self, preset: FocusPreset, complete_before_focus: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_value_async(self, focus: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncAction: ...
    def unlock_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class FocusSettings(winsdk.system.Object):
    wait_for_focus: winsdk.system.Boolean
    value: typing.Optional[typing.Optional[winsdk.system.UInt32]]
    mode: FocusMode
    distance: typing.Optional[typing.Optional[ManualFocusDistance]]
    disable_driver_fallback: winsdk.system.Boolean
    auto_focus_range: AutoFocusRange
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FocusSettings: ...
    def __new__(cls: typing.Type[FocusSettings]) -> FocusSettings:...

class HdrVideoControl(winsdk.system.Object):
    mode: HdrVideoMode
    supported: winsdk.system.Boolean
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[HdrVideoMode]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> HdrVideoControl: ...

class InfraredTorchControl(winsdk.system.Object):
    power: winsdk.system.Int32
    current_mode: InfraredTorchMode
    is_supported: winsdk.system.Boolean
    max_power: winsdk.system.Int32
    min_power: winsdk.system.Int32
    power_step: winsdk.system.Int32
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[InfraredTorchMode]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> InfraredTorchControl: ...

class IsoSpeedControl(winsdk.system.Object):
    preset: IsoSpeedPreset
    supported: winsdk.system.Boolean
    supported_presets: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IsoSpeedPreset]]
    auto: winsdk.system.Boolean
    max: winsdk.system.UInt32
    min: winsdk.system.UInt32
    step: winsdk.system.UInt32
    value: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IsoSpeedControl: ...
    def set_auto_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_preset_async(self, preset: IsoSpeedPreset) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_value_async(self, iso_speed: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncAction: ...

class KeypadPressedEventArgs(winsdk.system.Object):
    telephony_key: TelephonyKey
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KeypadPressedEventArgs: ...

class LowLagPhotoControl(winsdk.system.Object):
    thumbnail_format: winsdk.windows.media.mediaproperties.MediaThumbnailFormat
    thumbnail_enabled: winsdk.system.Boolean
    desired_thumbnail_size: winsdk.system.UInt32
    hardware_accelerated_thumbnail_supported: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LowLagPhotoControl: ...
    def get_current_frame_rate(self) -> typing.Optional[winsdk.windows.media.mediaproperties.MediaRatio]: ...
    def get_highest_concurrent_frame_rate(self, capture_properties: typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]) -> typing.Optional[winsdk.windows.media.mediaproperties.MediaRatio]: ...

class LowLagPhotoSequenceControl(winsdk.system.Object):
    thumbnail_format: winsdk.windows.media.mediaproperties.MediaThumbnailFormat
    thumbnail_enabled: winsdk.system.Boolean
    photos_per_second_limit: winsdk.system.Single
    past_photo_limit: winsdk.system.UInt32
    desired_thumbnail_size: winsdk.system.UInt32
    hardware_accelerated_thumbnail_supported: winsdk.system.UInt32
    max_past_photos: winsdk.system.UInt32
    max_photos_per_second: winsdk.system.Single
    supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LowLagPhotoSequenceControl: ...
    def get_current_frame_rate(self) -> typing.Optional[winsdk.windows.media.mediaproperties.MediaRatio]: ...
    def get_highest_concurrent_frame_rate(self, capture_properties: typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]) -> typing.Optional[winsdk.windows.media.mediaproperties.MediaRatio]: ...

class MediaDevice(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaDevice: ...
    @staticmethod
    def get_audio_capture_selector() -> str: ...
    @staticmethod
    def get_audio_render_selector() -> str: ...
    @staticmethod
    def get_default_audio_capture_id(role: AudioDeviceRole) -> str: ...
    @staticmethod
    def get_default_audio_render_id(role: AudioDeviceRole) -> str: ...
    @staticmethod
    def get_video_capture_selector() -> str: ...
    @staticmethod
    def add_default_audio_capture_device_changed(handler: winsdk.windows.foundation.TypedEventHandler[winsdk.system.Object, DefaultAudioCaptureDeviceChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_default_audio_capture_device_changed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_default_audio_render_device_changed(handler: winsdk.windows.foundation.TypedEventHandler[winsdk.system.Object, DefaultAudioRenderDeviceChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_default_audio_render_device_changed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaDeviceControl(winsdk.system.Object):
    capabilities: typing.Optional[MediaDeviceControlCapabilities]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaDeviceControl: ...
    def try_get_auto(self) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.Boolean]: ...
    def try_get_value(self) -> typing.Tuple[winsdk.system.Boolean, winsdk.system.Double]: ...
    def try_set_auto(self, value: winsdk.system.Boolean) -> winsdk.system.Boolean: ...
    def try_set_value(self, value: winsdk.system.Double) -> winsdk.system.Boolean: ...

class MediaDeviceControlCapabilities(winsdk.system.Object):
    auto_mode_supported: winsdk.system.Boolean
    default: winsdk.system.Double
    max: winsdk.system.Double
    min: winsdk.system.Double
    step: winsdk.system.Double
    supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaDeviceControlCapabilities: ...

class ModuleCommandResult(winsdk.system.Object):
    result: typing.Optional[winsdk.windows.storage.streams.IBuffer]
    status: SendCommandStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ModuleCommandResult: ...

class OpticalImageStabilizationControl(winsdk.system.Object):
    mode: OpticalImageStabilizationMode
    supported: winsdk.system.Boolean
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[OpticalImageStabilizationMode]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> OpticalImageStabilizationControl: ...

class PanelBasedOptimizationControl(winsdk.system.Object):
    panel: winsdk.windows.devices.enumeration.Panel
    is_supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PanelBasedOptimizationControl: ...

class PhotoConfirmationControl(winsdk.system.Object):
    pixel_format: winsdk.windows.media.mediaproperties.MediaPixelFormat
    enabled: winsdk.system.Boolean
    supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PhotoConfirmationControl: ...

class RedialRequestedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RedialRequestedEventArgs: ...
    def handled(self) -> None: ...

class RegionOfInterest(winsdk.system.Object):
    bounds: winsdk.windows.foundation.Rect
    auto_white_balance_enabled: winsdk.system.Boolean
    auto_focus_enabled: winsdk.system.Boolean
    auto_exposure_enabled: winsdk.system.Boolean
    weight: winsdk.system.UInt32
    type: RegionOfInterestType
    bounds_normalized: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RegionOfInterest: ...
    def __new__(cls: typing.Type[RegionOfInterest]) -> RegionOfInterest:...

class RegionsOfInterestControl(winsdk.system.Object):
    auto_exposure_supported: winsdk.system.Boolean
    auto_focus_supported: winsdk.system.Boolean
    auto_white_balance_supported: winsdk.system.Boolean
    max_regions: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RegionsOfInterestControl: ...
    def clear_regions_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def set_regions_async(self, regions: typing.Iterable[RegionOfInterest]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def set_regions_async(self, regions: typing.Iterable[RegionOfInterest], lock_values: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncAction: ...

class SceneModeControl(winsdk.system.Object):
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[CaptureSceneMode]]
    value: CaptureSceneMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SceneModeControl: ...
    def set_value_async(self, scene_mode: CaptureSceneMode) -> winsdk.windows.foundation.IAsyncAction: ...

class TorchControl(winsdk.system.Object):
    power_percent: winsdk.system.Single
    enabled: winsdk.system.Boolean
    power_supported: winsdk.system.Boolean
    supported: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TorchControl: ...

class VideoDeviceController(winsdk.system.Object):
    camera_occlusion_info: typing.Optional[CameraOcclusionInfo]
    primary_use: CaptureUse
    focus_control: typing.Optional[FocusControl]
    iso_speed_control: typing.Optional[IsoSpeedControl]
    low_lag_photo: typing.Optional[LowLagPhotoControl]
    white_balance_control: typing.Optional[WhiteBalanceControl]
    torch_control: typing.Optional[TorchControl]
    scene_mode_control: typing.Optional[SceneModeControl]
    regions_of_interest_control: typing.Optional[RegionsOfInterestControl]
    flash_control: typing.Optional[FlashControl]
    low_lag_photo_sequence: typing.Optional[LowLagPhotoSequenceControl]
    exposure_compensation_control: typing.Optional[ExposureCompensationControl]
    exposure_control: typing.Optional[ExposureControl]
    zoom_control: typing.Optional[ZoomControl]
    photo_confirmation_control: typing.Optional[PhotoConfirmationControl]
    variable_photo_sequence_controller: typing.Optional[winsdk.windows.media.devices.core.VariablePhotoSequenceController]
    desired_optimization: MediaCaptureOptimization
    advanced_photo_control: typing.Optional[AdvancedPhotoControl]
    exposure_priority_video_control: typing.Optional[ExposurePriorityVideoControl]
    hdr_video_control: typing.Optional[HdrVideoControl]
    optical_image_stabilization_control: typing.Optional[OpticalImageStabilizationControl]
    id: str
    video_temporal_denoising_control: typing.Optional[VideoTemporalDenoisingControl]
    infrared_torch_control: typing.Optional[InfraredTorchControl]
    panel_based_optimization_control: typing.Optional[PanelBasedOptimizationControl]
    digital_window_control: typing.Optional[DigitalWindowControl]
    zoom: typing.Optional[MediaDeviceControl]
    contrast: typing.Optional[MediaDeviceControl]
    backlight_compensation: typing.Optional[MediaDeviceControl]
    white_balance: typing.Optional[MediaDeviceControl]
    brightness: typing.Optional[MediaDeviceControl]
    exposure: typing.Optional[MediaDeviceControl]
    tilt: typing.Optional[MediaDeviceControl]
    roll: typing.Optional[MediaDeviceControl]
    hue: typing.Optional[MediaDeviceControl]
    pan: typing.Optional[MediaDeviceControl]
    focus: typing.Optional[MediaDeviceControl]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoDeviceController: ...
    def get_available_media_stream_properties(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]]: ...
    def get_device_property(self, property_id: str) -> typing.Optional[winsdk.system.Object]: ...
    def get_device_property_by_extended_id(self, extended_property_id: winsdk.system.Array[winsdk.system.UInt8], max_property_value_size: typing.Optional[winsdk.system.UInt32]) -> typing.Optional[VideoDeviceControllerGetDevicePropertyResult]: ...
    def get_device_property_by_id(self, property_id: str, max_property_value_size: typing.Optional[winsdk.system.UInt32]) -> typing.Optional[VideoDeviceControllerGetDevicePropertyResult]: ...
    def get_media_stream_properties(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType) -> typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]: ...
    def set_device_property(self, property_id: str, property_value: typing.Optional[winsdk.system.Object]) -> None: ...
    def set_device_property_by_extended_id(self, extended_property_id: winsdk.system.Array[winsdk.system.UInt8], property_value: winsdk.system.Array[winsdk.system.UInt8]) -> VideoDeviceControllerSetDevicePropertyStatus: ...
    def set_device_property_by_id(self, property_id: str, property_value: typing.Optional[winsdk.system.Object]) -> VideoDeviceControllerSetDevicePropertyStatus: ...
    def set_media_stream_properties_async(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType, media_encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_acquire_exclusive_control(self, device_id: str, mode: winsdk.windows.media.capture.MediaCaptureDeviceExclusiveControlReleaseMode) -> winsdk.system.Boolean: ...
    def try_get_powerline_frequency(self) -> typing.Tuple[winsdk.system.Boolean, winsdk.windows.media.capture.PowerlineFrequency]: ...
    def try_set_powerline_frequency(self, value: winsdk.windows.media.capture.PowerlineFrequency) -> winsdk.system.Boolean: ...

class VideoDeviceControllerGetDevicePropertyResult(winsdk.system.Object):
    status: VideoDeviceControllerGetDevicePropertyStatus
    value: typing.Optional[winsdk.system.Object]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoDeviceControllerGetDevicePropertyResult: ...

class VideoTemporalDenoisingControl(winsdk.system.Object):
    mode: VideoTemporalDenoisingMode
    supported: winsdk.system.Boolean
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[VideoTemporalDenoisingMode]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoTemporalDenoisingControl: ...

class WhiteBalanceControl(winsdk.system.Object):
    max: winsdk.system.UInt32
    min: winsdk.system.UInt32
    preset: ColorTemperaturePreset
    step: winsdk.system.UInt32
    supported: winsdk.system.Boolean
    value: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> WhiteBalanceControl: ...
    def set_preset_async(self, preset: ColorTemperaturePreset) -> winsdk.windows.foundation.IAsyncAction: ...
    def set_value_async(self, temperature: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncAction: ...

class ZoomControl(winsdk.system.Object):
    value: winsdk.system.Single
    max: winsdk.system.Single
    min: winsdk.system.Single
    step: winsdk.system.Single
    supported: winsdk.system.Boolean
    mode: ZoomTransitionMode
    supported_modes: typing.Optional[winsdk.windows.foundation.collections.IVectorView[ZoomTransitionMode]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ZoomControl: ...
    def configure(self, settings: typing.Optional[ZoomSettings]) -> None: ...

class ZoomSettings(winsdk.system.Object):
    value: winsdk.system.Single
    mode: ZoomTransitionMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ZoomSettings: ...
    def __new__(cls: typing.Type[ZoomSettings]) -> ZoomSettings:...

class IDefaultAudioDeviceChangedEventArgs(winsdk.system.Object):
    id: str
    role: AudioDeviceRole
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IDefaultAudioDeviceChangedEventArgs: ...

class IMediaDeviceController(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaDeviceController: ...
    def get_available_media_stream_properties(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]]: ...
    def get_media_stream_properties(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType) -> typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]: ...
    def set_media_stream_properties_async(self, media_stream_type: winsdk.windows.media.capture.MediaStreamType, media_encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.IMediaEncodingProperties]) -> winsdk.windows.foundation.IAsyncAction: ...

CallControlEventHandler = typing.Callable[[typing.Optional[CallControl]], None]

DialRequestedEventHandler = typing.Callable[[typing.Optional[CallControl], typing.Optional[DialRequestedEventArgs]], None]

KeypadPressedEventHandler = typing.Callable[[typing.Optional[CallControl], typing.Optional[KeypadPressedEventArgs]], None]

RedialRequestedEventHandler = typing.Callable[[typing.Optional[CallControl], typing.Optional[RedialRequestedEventArgs]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.WindowManagement")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.ui.composition
except ImportError:
    pass

class AppWindowClosedReason(enum.IntEnum):
    OTHER = 0
    APP_INITIATED = 1
    USER_INITIATED = 2

class AppWindowFrameStyle(enum.IntEnum):
    DEFAULT = 0
    NO_FRAME = 1

class AppWindowPresentationKind(enum.IntEnum):
    DEFAULT = 0
    COMPACT_OVERLAY = 1
    FULL_SCREEN = 2

class AppWindowTitleBarVisibility(enum.IntEnum):
    DEFAULT = 0
    ALWAYS_HIDDEN = 1

class WindowingEnvironmentKind(enum.IntEnum):
    UNKNOWN = 0
    OVERLAPPED = 1
    TILED = 2

_ns_module._register_AppWindowClosedReason(AppWindowClosedReason)
_ns_module._register_AppWindowFrameStyle(AppWindowFrameStyle)
_ns_module._register_AppWindowPresentationKind(AppWindowPresentationKind)
_ns_module._register_AppWindowTitleBarVisibility(AppWindowTitleBarVisibility)
_ns_module._register_WindowingEnvironmentKind(WindowingEnvironmentKind)

AppWindow = _ns_module.AppWindow
AppWindowChangedEventArgs = _ns_module.AppWindowChangedEventArgs
AppWindowCloseRequestedEventArgs = _ns_module.AppWindowCloseRequestedEventArgs
AppWindowClosedEventArgs = _ns_module.AppWindowClosedEventArgs
AppWindowFrame = _ns_module.AppWindowFrame
AppWindowPlacement = _ns_module.AppWindowPlacement
AppWindowPresentationConfiguration = _ns_module.AppWindowPresentationConfiguration
AppWindowPresenter = _ns_module.AppWindowPresenter
AppWindowTitleBar = _ns_module.AppWindowTitleBar
AppWindowTitleBarOcclusion = _ns_module.AppWindowTitleBarOcclusion
CompactOverlayPresentationConfiguration = _ns_module.CompactOverlayPresentationConfiguration
DefaultPresentationConfiguration = _ns_module.DefaultPresentationConfiguration
DisplayRegion = _ns_module.DisplayRegion
FullScreenPresentationConfiguration = _ns_module.FullScreenPresentationConfiguration
WindowServices = _ns_module.WindowServices
WindowingEnvironment = _ns_module.WindowingEnvironment
WindowingEnvironmentAddedEventArgs = _ns_module.WindowingEnvironmentAddedEventArgs
WindowingEnvironmentChangedEventArgs = _ns_module.WindowingEnvironmentChangedEventArgs
WindowingEnvironmentRemovedEventArgs = _ns_module.WindowingEnvironmentRemovedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Web")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class WebErrorStatus(enum.IntEnum):
    UNKNOWN = 0
    CERTIFICATE_COMMON_NAME_IS_INCORRECT = 1
    CERTIFICATE_EXPIRED = 2
    CERTIFICATE_CONTAINS_ERRORS = 3
    CERTIFICATE_REVOKED = 4
    CERTIFICATE_IS_INVALID = 5
    SERVER_UNREACHABLE = 6
    TIMEOUT = 7
    ERROR_HTTP_INVALID_SERVER_RESPONSE = 8
    CONNECTION_ABORTED = 9
    CONNECTION_RESET = 10
    DISCONNECTED = 11
    HTTP_TO_HTTPS_ON_REDIRECTION = 12
    HTTPS_TO_HTTP_ON_REDIRECTION = 13
    CANNOT_CONNECT = 14
    HOST_NAME_NOT_RESOLVED = 15
    OPERATION_CANCELED = 16
    REDIRECT_FAILED = 17
    UNEXPECTED_STATUS_CODE = 18
    UNEXPECTED_REDIRECTION = 19
    UNEXPECTED_CLIENT_ERROR = 20
    UNEXPECTED_SERVER_ERROR = 21
    INSUFFICIENT_RANGE_SUPPORT = 22
    MISSING_CONTENT_LENGTH_SUPPORT = 23
    MULTIPLE_CHOICES = 300
    MOVED_PERMANENTLY = 301
    FOUND = 302
    SEE_OTHER = 303
    NOT_MODIFIED = 304
    USE_PROXY = 305
    TEMPORARY_REDIRECT = 307
    BAD_REQUEST = 400
    UNAUTHORIZED = 401
    PAYMENT_REQUIRED = 402
    FORBIDDEN = 403
    NOT_FOUND = 404
    METHOD_NOT_ALLOWED = 405
    NOT_ACCEPTABLE = 406
    PROXY_AUTHENTICATION_REQUIRED = 407
    REQUEST_TIMEOUT = 408
    CONFLICT = 409
    GONE = 410
    LENGTH_REQUIRED = 411
    PRECONDITION_FAILED = 412
    REQUEST_ENTITY_TOO_LARGE = 413
    REQUEST_URI_TOO_LONG = 414
    UNSUPPORTED_MEDIA_TYPE = 415
    REQUESTED_RANGE_NOT_SATISFIABLE = 416
    EXPECTATION_FAILED = 417
    INTERNAL_SERVER_ERROR = 500
    NOT_IMPLEMENTED = 501
    BAD_GATEWAY = 502
    SERVICE_UNAVAILABLE = 503
    GATEWAY_TIMEOUT = 504
    HTTP_VERSION_NOT_SUPPORTED = 505

_ns_module._register_WebErrorStatus(WebErrorStatus)

WebError = _ns_module.WebError
IUriToStreamResolver = _ns_module.IUriToStreamResolver



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.management.deployment
import winsdk.windows.system

class AppInstallState(enum.IntEnum):
    PENDING = 0
    STARTING = 1
    ACQUIRING_LICENSE = 2
    DOWNLOADING = 3
    RESTORING_DATA = 4
    INSTALLING = 5
    COMPLETED = 6
    CANCELED = 7
    PAUSED = 8
    ERROR = 9
    PAUSED_LOW_BATTERY = 10
    PAUSED_WI_FI_RECOMMENDED = 11
    PAUSED_WI_FI_REQUIRED = 12
    READY_TO_DOWNLOAD = 13

class AppInstallType(enum.IntEnum):
    INSTALL = 0
    UPDATE = 1
    REPAIR = 2

class AppInstallationToastNotificationMode(enum.IntEnum):
    DEFAULT = 0
    TOAST = 1
    TOAST_WITHOUT_POPUP = 2
    NO_TOAST = 3

class AutoUpdateSetting(enum.IntEnum):
    DISABLED = 0
    ENABLED = 1
    DISABLED_BY_POLICY = 2
    ENABLED_BY_POLICY = 3

class GetEntitlementStatus(enum.IntEnum):
    SUCCEEDED = 0
    NO_STORE_ACCOUNT = 1
    NETWORK_ERROR = 2
    SERVER_ERROR = 3

Self = typing.TypeVar('Self')

class AppInstallItem(winsdk.system.Object):
    install_type: AppInstallType
    is_user_initiated: winsdk.system.Boolean
    package_family_name: str
    product_id: str
    children: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]
    item_operations_might_affect_other_items: winsdk.system.Boolean
    launch_after_install: winsdk.system.Boolean
    pin_to_taskbar_after_install: winsdk.system.Boolean
    pin_to_start_after_install: winsdk.system.Boolean
    pin_to_desktop_after_install: winsdk.system.Boolean
    install_in_progress_toast_notification_mode: AppInstallationToastNotificationMode
    completed_install_toast_notification_mode: AppInstallationToastNotificationMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstallItem: ...
    @typing.overload
    def cancel(self) -> None: ...
    @typing.overload
    def cancel(self, correlation_vector: str) -> None: ...
    def get_current_status(self) -> typing.Optional[AppInstallStatus]: ...
    @typing.overload
    def pause(self) -> None: ...
    @typing.overload
    def pause(self, correlation_vector: str) -> None: ...
    @typing.overload
    def restart(self) -> None: ...
    @typing.overload
    def restart(self, correlation_vector: str) -> None: ...
    def add_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppInstallItem, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppInstallItem, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppInstallManager(winsdk.system.Object):
    auto_update_setting: AutoUpdateSetting
    acquisition_identity: str
    app_install_items: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]
    app_install_items_with_group_support: typing.Optional[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]
    can_install_for_all_users: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstallManager: ...
    def __new__(cls: typing.Type[AppInstallManager]) -> AppInstallManager:...
    @typing.overload
    def cancel(self, product_id: str) -> None: ...
    @typing.overload
    def cancel(self, product_id: str, correlation_vector: str) -> None: ...
    def get_free_device_entitlement_async(self, store_id: str, campaign_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[GetEntitlementResult]: ...
    def get_free_user_entitlement_async(self, store_id: str, campaign_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[GetEntitlementResult]: ...
    def get_free_user_entitlement_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], store_id: str, campaign_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[GetEntitlementResult]: ...
    @typing.overload
    def get_is_app_allowed_to_install_async(self, product_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @typing.overload
    def get_is_app_allowed_to_install_async(self, product_id: str, sku_id: str, catalog_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_is_app_allowed_to_install_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], product_id: str, sku_id: str, catalog_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_is_applicable_async(self, product_id: str, sku_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_is_applicable_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], product_id: str, sku_id: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_is_package_identity_allowed_to_install_async(self, correlation_vector: str, package_identity_name: str, publisher_certificate_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_is_package_identity_allowed_to_install_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], correlation_vector: str, package_identity_name: str, publisher_certificate_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def is_store_blocked_by_policy_async(self, store_client_name: str, store_client_publisher: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def move_to_front_of_download_queue(self, product_id: str, correlation_vector: str) -> None: ...
    @typing.overload
    def pause(self, product_id: str) -> None: ...
    @typing.overload
    def pause(self, product_id: str, correlation_vector: str) -> None: ...
    @typing.overload
    def restart(self, product_id: str) -> None: ...
    @typing.overload
    def restart(self, product_id: str, correlation_vector: str) -> None: ...
    @typing.overload
    def search_for_all_updates_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def search_for_all_updates_async(self, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def search_for_all_updates_async(self, correlation_vector: str, client_id: str, update_options: typing.Optional[AppUpdateOptions]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def search_for_all_updates_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def search_for_all_updates_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], correlation_vector: str, client_id: str, update_options: typing.Optional[AppUpdateOptions]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def search_for_updates_async(self, product_id: str, sku_id: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def search_for_updates_async(self, product_id: str, sku_id: str, catalog_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def search_for_updates_async(self, product_id: str, sku_id: str, correlation_vector: str, client_id: str, update_options: typing.Optional[AppUpdateOptions]) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def search_for_updates_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], product_id: str, sku_id: str, catalog_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def search_for_updates_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], product_id: str, sku_id: str, correlation_vector: str, client_id: str, update_options: typing.Optional[AppUpdateOptions]) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def start_app_install_async(self, product_id: str, sku_id: str, repair: winsdk.system.Boolean, force_use_of_non_removable_storage: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def start_app_install_async(self, product_id: str, sku_id: str, repair: winsdk.system.Boolean, force_use_of_non_removable_storage: winsdk.system.Boolean, catalog_id: str, bundle_id: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def start_product_install_async(self, product_id: str, flight_id: str, client_id: str, correlation_vector: str, install_options: typing.Optional[AppInstallOptions]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def start_product_install_async(self, product_id: str, catalog_id: str, flight_id: str, client_id: str, repair: winsdk.system.Boolean, force_use_of_non_removable_storage: winsdk.system.Boolean, correlation_vector: str, target_volume: typing.Optional[winsdk.windows.management.deployment.PackageVolume]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def start_product_install_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], product_id: str, flight_id: str, client_id: str, correlation_vector: str, install_options: typing.Optional[AppInstallOptions]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def start_product_install_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], product_id: str, catalog_id: str, flight_id: str, client_id: str, repair: winsdk.system.Boolean, force_use_of_non_removable_storage: winsdk.system.Boolean, correlation_vector: str, target_volume: typing.Optional[winsdk.windows.management.deployment.PackageVolume]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[AppInstallItem]]: ...
    @typing.overload
    def update_app_by_package_family_name_async(self, package_family_name: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    @typing.overload
    def update_app_by_package_family_name_async(self, package_family_name: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    def update_app_by_package_family_name_for_user_async(self, user: typing.Optional[winsdk.windows.system.User], package_family_name: str, correlation_vector: str) -> winsdk.windows.foundation.IAsyncOperation[AppInstallItem]: ...
    def add_item_completed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppInstallManager, AppInstallManagerItemEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_completed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_item_status_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AppInstallManager, AppInstallManagerItemEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_item_status_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AppInstallManagerItemEventArgs(winsdk.system.Object):
    item: typing.Optional[AppInstallItem]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstallManagerItemEventArgs: ...

class AppInstallOptions(winsdk.system.Object):
    target_volume: typing.Optional[winsdk.windows.management.deployment.PackageVolume]
    repair: winsdk.system.Boolean
    launch_after_install: winsdk.system.Boolean
    force_use_of_non_removable_storage: winsdk.system.Boolean
    catalog_id: str
    allow_forced_app_restart: winsdk.system.Boolean
    stage_but_do_not_install: winsdk.system.Boolean
    pin_to_taskbar_after_install: winsdk.system.Boolean
    pin_to_start_after_install: winsdk.system.Boolean
    pin_to_desktop_after_install: winsdk.system.Boolean
    install_in_progress_toast_notification_mode: AppInstallationToastNotificationMode
    install_for_all_users: winsdk.system.Boolean
    extended_campaign_id: str
    completed_install_toast_notification_mode: AppInstallationToastNotificationMode
    campaign_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstallOptions: ...
    def __new__(cls: typing.Type[AppInstallOptions]) -> AppInstallOptions:...

class AppInstallStatus(winsdk.system.Object):
    bytes_downloaded: winsdk.system.UInt64
    download_size_in_bytes: winsdk.system.UInt64
    error_code: winsdk.windows.foundation.HResult
    install_state: AppInstallState
    percent_complete: winsdk.system.Double
    ready_for_launch: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    is_staged: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppInstallStatus: ...

class AppUpdateOptions(winsdk.system.Object):
    catalog_id: str
    allow_forced_app_restart: winsdk.system.Boolean
    automatically_download_and_install_update_if_found: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppUpdateOptions: ...
    def __new__(cls: typing.Type[AppUpdateOptions]) -> AppUpdateOptions:...

class GetEntitlementResult(winsdk.system.Object):
    status: GetEntitlementStatus
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GetEntitlementResult: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Spi.Provider")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class ProviderSpiMode(enum.IntEnum):
    MODE0 = 0
    MODE1 = 1
    MODE2 = 2
    MODE3 = 3

class ProviderSpiSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED = 1

_ns_module._register_ProviderSpiMode(ProviderSpiMode)
_ns_module._register_ProviderSpiSharingMode(ProviderSpiSharingMode)

ProviderSpiConnectionSettings = _ns_module.ProviderSpiConnectionSettings
ISpiControllerProvider = _ns_module.ISpiControllerProvider
ISpiDeviceProvider = _ns_module.ISpiDeviceProvider
ISpiProvider = _ns_module.ISpiProvider
